@@ -3,7 +3,7 @@ from django import forms
 
 class AllowForm(forms.Form):
     allow = forms.BooleanField(required=False)
-    redirect_uri = forms.URLField(widget=forms.HiddenInput())
+    redirect_uri = forms.CharField(widget=forms.HiddenInput())
     scopes = forms.CharField(required=False, widget=forms.HiddenInput())
     client_id = forms.CharField(widget=forms.HiddenInput())
     state = forms.CharField(required=False, widget=forms.HiddenInput())
