@@ -1,10 +1,9 @@
-import urllib
-from urlparse import urlparse, parse_qs
+from __future__ import unicode_literals
 
 from django.test import TestCase, RequestFactory
-from django.contrib.auth import get_user_model
 from django.core.urlresolvers import reverse
 
+from ..compat import urlparse, parse_qs, urlencode, get_user_model
 from ..models import Application
 from ..settings import oauth2_settings
 from ..views import ProtectedResourceView
@@ -46,7 +45,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'token',
             'state': 'random_state_string',
@@ -73,7 +72,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': 'fakeclientid',
             'response_type': 'token',
         })
@@ -88,7 +87,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'token',
         })
@@ -106,7 +105,7 @@ class TestImplicitAuthorizationCodeView(BaseTest):
         """
         self.client.login(username="test_user", password="123456")
 
-        query_string = urllib.urlencode({
+        query_string = urlencode({
             'client_id': self.application.client_id,
             'response_type': 'token',
             'redirect_uri': 'http://forbidden.it',
@@ -133,8 +132,9 @@ class TestImplicitAuthorizationCodeView(BaseTest):
 
         response = self.client.post(reverse('authorize'), data=form_data)
         self.assertEqual(response.status_code, 302)
-        self.assertIn('http://example.it/#access_token=', response['Location'])
-        self.assertIn('&state=random_state_string', response['Location'])
+        self.assertIn('http://example.it#', response['Location'])
+        self.assertIn('access_token=', response['Location'])
+        self.assertIn('state=random_state_string', response['Location'])
 
     def test_token_post_auth_deny(self):
         """
